# CombinedUserDetailStatus

A `CombinedUserDetailStatus` joins together all the information about a user necessary to perform most operations related to them. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user** | [**User**](User.md) |  | [optional] 
**mfa_challenge_methods** | [**list[MFAChallengeMethod]**](MFAChallengeMethod.md) | The Multifactor authentication challenge methods configured by the user. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


